Module: MultipleDbs::MultiConnectable

Extended by:
ActiveSupport::Concern
Defined in:
lib/multiple_dbs/multi_connectable.rb

Overview

This module should be included in your application ApplicationRecord. It define two class methods for your models. With this two methods you can setup and handle all the models from all the databases you defined.

Defined Under Namespace

Modules: ClassMethods